## Tables

| Table name | Description |
|------------|-------------|
|abc||
|acquisitiontype||
|aws1||
|aws_basestation||
|aws_elements||
|aws_lsi||
|aws_lsi1||
|aws_malawi1||
|aws_malawi12||
|aws_mss||
|aws_process_parameters||
|aws_rema1||
|aws_rwanda1||
|aws_rwanda4||
|aws_rwanda_rain||
|aws_sasscal1||
|aws_sites||
|aws_stations||
|aws_structures||
|aws_tahmo||
|aws_test||
|aws_toa5_bw1||
|aws_toa5_mg2||
|bufr_crex_data||
|bufr_crex_master||
|bufr_indicators||
|ccitt||
|climsoftusers||
|code_flag||
|data_forms||
|faultresolution||
|featuregeographicalposition||
|flags||
|flagtable||
|form_agro1||
|form_daily2||
|form_hourly||
|form_hourlywind||
|form_hourly_time_selection||
|form_monthly||
|form_synoptic2_tdcf||
|form_synoptic_2_ra1||
|gaps||
|instrument||
|instrumentfaultreport||
|instrumentinspection||
|language_translation||
|missing_data||
|missing_stats||
|obselement||
|observationfinal||
|observationinitial||
|observationschedule||
|obsscheduleclass||
|paperarchive||
|paperarchivedefinition||
|physicalfeature||
|physicalfeatureclass||
|qcabslimits||
|qcstatusdefinition||
|qctype||
|qc_interelement_1||
|qc_interelement_2||
|qc_interelement_relationship_definition||
|regkeys||
|routinereportdefinition||
|routinereporttransmission||
|seq_daily_element||
|seq_day||
|seq_element||
|seq_hour||
|seq_leap_year||
|seq_month||
|seq_monthly_element||
|seq_month_day||
|seq_month_day_element||
|seq_month_day_element_leap_yr||
|seq_month_day_leap_yr||
|seq_month_day_synoptime||
|seq_month_day_synoptime_leap_yr||
|seq_year||
|ss||
|station||
|stationelement||
|stationidalias||
|stationlocationhistory||
|stationnetworkdefinition||
|stationqualifier||
|synopfeature||
|tblproducts||
|tdcf_indicators||
|testing_aws||
|testing_aws1||
|tm_307073||
|tm_307080||
|tm_307081||
|tm_307082||
|tm_307083||
|tm_307084||
|tm_307086||
|tm_307089||
|tm_307091||
|tm_307092||
|tm_309052||
|userrecords||
